@@ -1,5 +1,3 @@
-# coding: utf-8
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -9,7 +7,7 @@
 
 from flask import request
 
-from ..db import ChatMessage, User
+from ..db import ChatMessage
 from . import api
 
 
