@@ -1,5 +1,3 @@
-# coding: utf-8
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -12,7 +10,7 @@ from flask import request
 from ..db import RadioStation
 
 from . import api, get_entity
-from .exceptions import Forbidden, MissingParameter, NotFound
+from .exceptions import Forbidden, MissingParameter
 
 
 @api.route("/getInternetRadioStations.view", methods=["GET", "POST"])
