@@ -16,7 +16,7 @@ from hashlib import sha1
 from pony.orm import Database, Required, Optional, Set, PrimaryKey, LongStr
 from pony.orm import ObjectNotFound, DatabaseError
 from pony.orm import buffer
-from pony.orm import min, max, avg, sum, count, exists
+from pony.orm import min, avg, sum, count, exists
 from pony.orm import db_session
 from urllib.parse import urlparse, parse_qsl
 from uuid import UUID, uuid4
@@ -46,7 +46,7 @@ def sqlite_case_insensitive_like(db, connection):
     cursor.execute("PRAGMA case_sensitive_like = OFF")
 
 
-class PathMixin(object):
+class PathMixin:
     @classmethod
     def get(cls, *args, **kwargs):
         if kwargs:
@@ -529,7 +529,7 @@ class Playlist(db.Entity):
             id=str(self.id),
             name=self.name
             if self.user.id == user.id
-            else "[%s] %s" % (self.user.name, self.name),
+            else "[{}] {}".format(self.user.name, self.name),
             owner=self.user.name,
             public=self.public,
             songCount=len(tracks),
