@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -7,6 +5,7 @@
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
+import unittest
 import uuid
 
 from pony.orm import db_session
@@ -18,7 +17,7 @@ from .apitestbase import ApiTestBase
 
 class AnnotationTestCase(ApiTestBase):
     def setUp(self):
-        super(AnnotationTestCase, self).setUp()
+        super().setUp()
 
         with db_session:
             root = Folder(name="Root", root=True, path="tests")
