@@ -1,6 +1,3 @@
-#!/usr/bin/env python
-# coding: utf-8
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
@@ -11,6 +8,7 @@
 
 import base64
 import flask.json
+import unittest
 
 from xml.etree import ElementTree
 
@@ -22,7 +20,7 @@ class ApiSetupTestCase(TestBase):
     __with_api__ = True
 
     def setUp(self):
-        super(ApiSetupTestCase, self).setUp()
+        super().setUp()
         self._patch_client()
 
     def __basic_auth_get(self, username, password):
